import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.math
import java.security
import java.security.cert
import java.security.spec
import java.util
import java.util.concurrent
import javax.security.auth.x500

class AppUriAuthenticationPolicy(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppUriAuthenticationPolicy]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppAndUriMappings(self) -> java.util.Map[java.lang.String, java.util.Map[android.net.Uri, java.lang.String]]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addAppAndUriMapping(self, appPackageName: str | java.lang.String, uri: android.net.Uri, alias: str | java.lang.String, /) -> AppUriAuthenticationPolicy.Builder: ...
        def build(self) -> AppUriAuthenticationPolicy: ...

class AttestedKeyPair(java.lang.Object):
    def __init__(self, keyPair: java.security.KeyPair, attestationRecord: java.util.List[java.security.cert.Certificate], /) -> None: ...
    def getAttestationRecord(self) -> java.util.List[java.security.cert.Certificate]: ...
    def getKeyPair(self) -> java.security.KeyPair | None: ...

class ConfirmationAlreadyPresentingException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class ConfirmationCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onCanceled(self) -> None: ...
    def onConfirmed(self, dataThatWasConfirmed: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def onDismissed(self) -> None: ...
    def onError(self, e: java.lang.Throwable, /) -> None: ...

class ConfirmationNotAvailableException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class ConfirmationPrompt(java.lang.Object):
    def cancelPrompt(self) -> None: ...
    @staticmethod
    def isSupported(context: android.content.Context, /) -> bool: ...
    def presentPrompt(self, executor: java.util.concurrent.Executor, callback: ConfirmationCallback, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def build(self) -> ConfirmationPrompt: ...
        def setExtraData(self, extraData: java.chaquopy.JavaArrayJByte, /) -> ConfirmationPrompt.Builder: ...
        def setPromptText(self, promptText: java.lang.CharSequence, /) -> ConfirmationPrompt.Builder: ...

class FileIntegrityManager(java.lang.Object):
    def isApkVeritySupported(self) -> bool: ...
    def isAppSourceCertificateTrusted(self, certificate: java.security.cert.X509Certificate, /) -> bool: ...

class KeyChain(java.lang.Object):
    ACTION_KEYCHAIN_CHANGED: typing.ClassVar[str] = ...
    ACTION_KEY_ACCESS_CHANGED: typing.ClassVar[str] = ...
    ACTION_STORAGE_CHANGED: typing.ClassVar[str] = ...
    ACTION_TRUST_STORE_CHANGED: typing.ClassVar[str] = ...
    EXTRA_CERTIFICATE: typing.ClassVar[str] = ...
    EXTRA_KEY_ACCESSIBLE: typing.ClassVar[str] = ...
    EXTRA_KEY_ALIAS: typing.ClassVar[str] = ...
    EXTRA_NAME: typing.ClassVar[str] = ...
    EXTRA_PKCS12: typing.ClassVar[str] = ...
    KEY_ALIAS_SELECTION_DENIED: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def choosePrivateKeyAlias(activity: android.app.Activity, response: KeyChainAliasCallback, keyTypes: java.chaquopy.JavaArray[java.lang.String], issuers: java.chaquopy.JavaArray[java.security.Principal], uri: android.net.Uri, alias: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def choosePrivateKeyAlias(activity: android.app.Activity, response: KeyChainAliasCallback, keyTypes: java.chaquopy.JavaArray[java.lang.String], issuers: java.chaquopy.JavaArray[java.security.Principal], host: str | java.lang.String, port: int | java.jint | java.lang.Integer, alias: str | java.lang.String, /) -> None: ...
    @staticmethod
    def createInstallIntent() -> android.content.Intent: ...
    @staticmethod
    def createManageCredentialsIntent(policy: AppUriAuthenticationPolicy, /) -> android.content.Intent: ...
    @staticmethod
    def getCertificateChain(context: android.content.Context, alias: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.security.cert.X509Certificate] | None: ...
    @staticmethod
    def getCredentialManagementAppPolicy(context: android.content.Context, /) -> AppUriAuthenticationPolicy: ...
    @staticmethod
    def getPrivateKey(context: android.content.Context, alias: str | java.lang.String, /) -> java.security.PrivateKey | None: ...
    @staticmethod
    def isBoundKeyAlgorithm(algorithm: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isCredentialManagementApp(context: android.content.Context, /) -> bool: ...
    @staticmethod
    def isKeyAlgorithmSupported(algorithm: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def removeCredentialManagementApp(context: android.content.Context, /) -> bool: ...

class KeyChainAliasCallback(java.lang.Object):
    def alias(self, arg1: str | java.lang.String, /) -> None: ...

class KeyChainException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, detailMessage: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class KeyPairGeneratorSpec(java.security.spec.AlgorithmParameterSpec):
    def getAlgorithmParameterSpec(self) -> java.security.spec.AlgorithmParameterSpec: ...
    def getContext(self) -> android.content.Context: ...
    def getEndDate(self) -> java.util.Date: ...
    def getKeySize(self) -> int: ...
    def getKeyType(self) -> str | None: ...
    def getKeystoreAlias(self) -> str: ...
    def getSerialNumber(self) -> java.math.BigInteger: ...
    def getStartDate(self) -> java.util.Date: ...
    def getSubjectDN(self) -> javax.security.auth.x500.X500Principal: ...
    def isEncryptionRequired(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def build(self) -> KeyPairGeneratorSpec: ...
        def setAlgorithmParameterSpec(self, spec: java.security.spec.AlgorithmParameterSpec, /) -> KeyPairGeneratorSpec.Builder: ...
        def setAlias(self, alias: str | java.lang.String, /) -> KeyPairGeneratorSpec.Builder: ...
        def setEncryptionRequired(self) -> KeyPairGeneratorSpec.Builder: ...
        def setEndDate(self, endDate: java.util.Date, /) -> KeyPairGeneratorSpec.Builder: ...
        def setKeySize(self, keySize: int | java.jint | java.lang.Integer, /) -> KeyPairGeneratorSpec.Builder: ...
        def setKeyType(self, keyType: str | java.lang.String, /) -> KeyPairGeneratorSpec.Builder: ...
        def setSerialNumber(self, serialNumber: java.math.BigInteger, /) -> KeyPairGeneratorSpec.Builder: ...
        def setStartDate(self, startDate: java.util.Date, /) -> KeyPairGeneratorSpec.Builder: ...
        def setSubject(self, subject: javax.security.auth.x500.X500Principal, /) -> KeyPairGeneratorSpec.Builder: ...

class KeyStoreException(java.lang.Exception):
    ERROR_ATTESTATION_CHALLENGE_TOO_LARGE: typing.ClassVar[int] = ...
    ERROR_ATTESTATION_KEYS_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_ID_ATTESTATION_FAILURE: typing.ClassVar[int] = ...
    ERROR_INCORRECT_USAGE: typing.ClassVar[int] = ...
    ERROR_INTERNAL_SYSTEM_ERROR: typing.ClassVar[int] = ...
    ERROR_KEYMINT_FAILURE: typing.ClassVar[int] = ...
    ERROR_KEYSTORE_FAILURE: typing.ClassVar[int] = ...
    ERROR_KEYSTORE_UNINITIALIZED: typing.ClassVar[int] = ...
    ERROR_KEY_CORRUPTED: typing.ClassVar[int] = ...
    ERROR_KEY_DOES_NOT_EXIST: typing.ClassVar[int] = ...
    ERROR_KEY_NOT_TEMPORALLY_VALID: typing.ClassVar[int] = ...
    ERROR_KEY_OPERATION_EXPIRED: typing.ClassVar[int] = ...
    ERROR_OTHER: typing.ClassVar[int] = ...
    ERROR_PERMISSION_DENIED: typing.ClassVar[int] = ...
    ERROR_UNIMPLEMENTED: typing.ClassVar[int] = ...
    ERROR_USER_AUTHENTICATION_REQUIRED: typing.ClassVar[int] = ...
    RETRY_AFTER_NEXT_REBOOT: typing.ClassVar[int] = ...
    RETRY_NEVER: typing.ClassVar[int] = ...
    RETRY_WHEN_CONNECTIVITY_AVAILABLE: typing.ClassVar[int] = ...
    RETRY_WITH_EXPONENTIAL_BACKOFF: typing.ClassVar[int] = ...
    def getNumericErrorCode(self) -> int: ...
    def getRetryPolicy(self) -> int: ...
    def isSystemError(self) -> bool: ...
    def isTransientFailure(self) -> bool: ...
    def requiresUserAuthentication(self) -> bool: ...
    def toString(self) -> str: ...

class KeyStoreParameter(java.security.KeyStore.ProtectionParameter):
    def isEncryptionRequired(self) -> bool: ...

    class Builder(java.lang.Object):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def build(self) -> KeyStoreParameter: ...
        def setEncryptionRequired(self, required: bool | java.jboolean | java.lang.Boolean, /) -> KeyStoreParameter.Builder: ...

class NetworkSecurityPolicy(java.lang.Object):
    @staticmethod
    def getInstance() -> NetworkSecurityPolicy: ...
    def isCertificateTransparencyVerificationRequired(self, hostname: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def isCleartextTrafficPermitted(self) -> bool: ...
    @typing.overload
    def isCleartextTrafficPermitted(self, hostname: str | java.lang.String, /) -> bool: ...



import typing

import android.adservices.common
import android.content
import android.net
import android.os
import android.view
import java
import java.lang
import java.time
import java.util
import java.util.concurrent

class DeletionRequest(java.lang.Object):
    DELETION_MODE_ALL: typing.ClassVar[int] = ...
    DELETION_MODE_EXCLUDE_INTERNAL_DATA: typing.ClassVar[int] = ...
    MATCH_BEHAVIOR_DELETE: typing.ClassVar[int] = ...
    MATCH_BEHAVIOR_PRESERVE: typing.ClassVar[int] = ...
    def getDeletionMode(self) -> int: ...
    def getDomainUris(self) -> java.util.List[android.net.Uri]: ...
    def getEnd(self) -> java.time.Instant: ...
    def getMatchBehavior(self) -> int: ...
    def getOriginUris(self) -> java.util.List[android.net.Uri]: ...
    def getStart(self) -> java.time.Instant: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> DeletionRequest: ...
        def setDeletionMode(self, deletionMode: int | java.jint | java.lang.Integer, /) -> DeletionRequest.Builder: ...
        def setDomainUris(self, domainUris: java.util.List[android.net.Uri], /) -> DeletionRequest.Builder: ...
        def setEnd(self, end: java.time.Instant, /) -> DeletionRequest.Builder: ...
        def setMatchBehavior(self, matchBehavior: int | java.jint | java.lang.Integer, /) -> DeletionRequest.Builder: ...
        def setOriginUris(self, originUris: java.util.List[android.net.Uri], /) -> DeletionRequest.Builder: ...
        def setStart(self, start: java.time.Instant, /) -> DeletionRequest.Builder: ...

class MeasurementManager(java.lang.Object):
    MEASUREMENT_API_STATE_DISABLED: typing.ClassVar[int] = ...
    MEASUREMENT_API_STATE_ENABLED: typing.ClassVar[int] = ...
    @typing.overload
    def deleteRegistrations(self, deletionRequest: DeletionRequest, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def deleteRegistrations(self, deletionRequest: DeletionRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @staticmethod
    def get(context: android.content.Context, /) -> MeasurementManager: ...
    @typing.overload
    def getMeasurementApiStatus(self, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Integer, java.lang.Exception], /) -> None: ...
    @typing.overload
    def getMeasurementApiStatus(self, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Integer, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerSource(self, request: SourceRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerSource(self, request: SourceRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerSource(self, attributionSource: android.net.Uri, inputEvent: android.view.InputEvent, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerSource(self, attributionSource: android.net.Uri, inputEvent: android.view.InputEvent, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerTrigger(self, trigger: android.net.Uri, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerTrigger(self, trigger: android.net.Uri, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerWebSource(self, request: WebSourceRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerWebSource(self, request: WebSourceRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerWebTrigger(self, request: WebTriggerRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.adservices.common.AdServicesOutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...
    @typing.overload
    def registerWebTrigger(self, request: WebTriggerRegistrationRequest, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Object, java.lang.Exception], /) -> None: ...

class SourceRegistrationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SourceRegistrationRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getInputEvent(self) -> android.view.InputEvent | None: ...
    def getRegistrationUris(self) -> java.util.List[android.net.Uri]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, registrationUris: java.util.List[android.net.Uri], /) -> None: ...
        def build(self) -> SourceRegistrationRequest: ...
        def setInputEvent(self, inputEvent: android.view.InputEvent, /) -> SourceRegistrationRequest.Builder: ...

class WebSourceParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WebSourceParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getRegistrationUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def isDebugKeyAllowed(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, registrationUri: android.net.Uri, /) -> None: ...
        def build(self) -> WebSourceParams: ...
        def setDebugKeyAllowed(self, debugKeyAllowed: bool | java.jboolean | java.lang.Boolean, /) -> WebSourceParams.Builder: ...

class WebSourceRegistrationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WebSourceRegistrationRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppDestination(self) -> android.net.Uri | None: ...
    def getInputEvent(self) -> android.view.InputEvent | None: ...
    def getSourceParams(self) -> java.util.List[WebSourceParams]: ...
    def getTopOriginUri(self) -> android.net.Uri: ...
    def getVerifiedDestination(self) -> android.net.Uri | None: ...
    def getWebDestination(self) -> android.net.Uri | None: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, webSourceParams: java.util.List[WebSourceParams], topOriginUri: android.net.Uri, /) -> None: ...
        def build(self) -> WebSourceRegistrationRequest: ...
        def setAppDestination(self, appDestination: android.net.Uri, /) -> WebSourceRegistrationRequest.Builder: ...
        def setInputEvent(self, inputEvent: android.view.InputEvent, /) -> WebSourceRegistrationRequest.Builder: ...
        def setVerifiedDestination(self, verifiedDestination: android.net.Uri, /) -> WebSourceRegistrationRequest.Builder: ...
        def setWebDestination(self, webDestination: android.net.Uri, /) -> WebSourceRegistrationRequest.Builder: ...

class WebTriggerParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WebTriggerParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getRegistrationUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def isDebugKeyAllowed(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, registrationUri: android.net.Uri, /) -> None: ...
        def build(self) -> WebTriggerParams: ...
        def setDebugKeyAllowed(self, debugKeyAllowed: bool | java.jboolean | java.lang.Boolean, /) -> WebTriggerParams.Builder: ...

class WebTriggerRegistrationRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[WebTriggerRegistrationRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDestination(self) -> android.net.Uri: ...
    def getTriggerParams(self) -> java.util.List[WebTriggerParams]: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, webTriggerParams: java.util.List[WebTriggerParams], destination: android.net.Uri, /) -> None: ...
        def build(self) -> WebTriggerRegistrationRequest: ...



import typing

import android.app
import android.content
import android.content.pm
import android.graphics
import android.media
import android.media.tv
import android.net
import android.net.http
import android.os
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AppLinkInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppLinkInfo]] = ...
    def __init__(self, packageName: str | java.lang.String, className: str | java.lang.String, uriString: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getComponentName(self) -> android.content.ComponentName: ...
    def getUri(self) -> android.net.Uri: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TvInteractiveAppManager(java.lang.Object):
    ACTION_APP_LINK_COMMAND: typing.ClassVar[str] = ...
    APP_LINK_KEY_BACK_URI: typing.ClassVar[str] = ...
    APP_LINK_KEY_CLASS_NAME: typing.ClassVar[str] = ...
    APP_LINK_KEY_COMMAND_TYPE: typing.ClassVar[str] = ...
    APP_LINK_KEY_PACKAGE_NAME: typing.ClassVar[str] = ...
    APP_LINK_KEY_SERVICE_ID: typing.ClassVar[str] = ...
    ERROR_BLOCKED: typing.ClassVar[int] = ...
    ERROR_ENCRYPTED: typing.ClassVar[int] = ...
    ERROR_NONE: typing.ClassVar[int] = ...
    ERROR_NOT_SUPPORTED: typing.ClassVar[int] = ...
    ERROR_RESOURCE_UNAVAILABLE: typing.ClassVar[int] = ...
    ERROR_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_UNKNOWN_CHANNEL: typing.ClassVar[int] = ...
    ERROR_WEAK_SIGNAL: typing.ClassVar[int] = ...
    INTENT_KEY_BI_INTERACTIVE_APP_TYPE: typing.ClassVar[str] = ...
    INTENT_KEY_BI_INTERACTIVE_APP_URI: typing.ClassVar[str] = ...
    INTENT_KEY_CHANNEL_URI: typing.ClassVar[str] = ...
    INTENT_KEY_COMMAND_TYPE: typing.ClassVar[str] = ...
    INTENT_KEY_INTERACTIVE_APP_SERVICE_ID: typing.ClassVar[str] = ...
    INTENT_KEY_TV_INPUT_ID: typing.ClassVar[str] = ...
    INTERACTIVE_APP_STATE_ERROR: typing.ClassVar[int] = ...
    INTERACTIVE_APP_STATE_RUNNING: typing.ClassVar[int] = ...
    INTERACTIVE_APP_STATE_STOPPED: typing.ClassVar[int] = ...
    SERVICE_STATE_ERROR: typing.ClassVar[int] = ...
    SERVICE_STATE_PREPARING: typing.ClassVar[int] = ...
    SERVICE_STATE_READY: typing.ClassVar[int] = ...
    SERVICE_STATE_UNREALIZED: typing.ClassVar[int] = ...
    TELETEXT_APP_STATE_ERROR: typing.ClassVar[int] = ...
    TELETEXT_APP_STATE_HIDE: typing.ClassVar[int] = ...
    TELETEXT_APP_STATE_SHOW: typing.ClassVar[int] = ...
    def getAppLinkInfoList(self) -> java.util.List[AppLinkInfo]: ...
    def getTvInteractiveAppServiceList(self) -> java.util.List[TvInteractiveAppServiceInfo]: ...
    def registerAppLinkInfo(self, tvIAppServiceId: str | java.lang.String, appLinkInfo: AppLinkInfo, /) -> None: ...
    def registerCallback(self, executor: java.util.concurrent.Executor, callback: TvInteractiveAppManager.TvInteractiveAppCallback, /) -> None: ...
    def sendAppLinkCommand(self, tvIAppServiceId: str | java.lang.String, command: android.os.Bundle, /) -> None: ...
    def unregisterAppLinkInfo(self, tvIAppServiceId: str | java.lang.String, appLinkInfo: AppLinkInfo, /) -> None: ...
    def unregisterCallback(self, callback: TvInteractiveAppManager.TvInteractiveAppCallback, /) -> None: ...

    class TvInteractiveAppCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onInteractiveAppServiceAdded(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onInteractiveAppServiceRemoved(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onInteractiveAppServiceUpdated(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onTvInteractiveAppServiceStateChanged(self, iAppServiceId: str | java.lang.String, type: int | java.jint | java.lang.Integer, state: int | java.jint | java.lang.Integer, err: int | java.jint | java.lang.Integer, /) -> None: ...

class TvInteractiveAppService(android.app.Service):
    COMMAND_PARAMETER_KEY_CHANGE_CHANNEL_QUIETLY: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_CHANNEL_URI: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_INPUT_ID: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_PLAYBACK_PARAMS: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_PROGRAM_URI: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_STOP_MODE: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_TIME_POSITION: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_TIME_SHIFT_MODE: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_TRACK_ID: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_TRACK_TYPE: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_KEY_VOLUME: typing.ClassVar[str] = ...
    COMMAND_PARAMETER_VALUE_STOP_MODE_BLANK: typing.ClassVar[int] = ...
    COMMAND_PARAMETER_VALUE_STOP_MODE_FREEZE: typing.ClassVar[int] = ...
    PLAYBACK_COMMAND_TYPE_SELECT_TRACK: typing.ClassVar[str] = ...
    PLAYBACK_COMMAND_TYPE_SET_STREAM_VOLUME: typing.ClassVar[str] = ...
    PLAYBACK_COMMAND_TYPE_STOP: typing.ClassVar[str] = ...
    PLAYBACK_COMMAND_TYPE_TUNE: typing.ClassVar[str] = ...
    PLAYBACK_COMMAND_TYPE_TUNE_NEXT: typing.ClassVar[str] = ...
    PLAYBACK_COMMAND_TYPE_TUNE_PREV: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_PAUSE: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_PLAY: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_RESUME: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_SEEK_TO: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_SET_MODE: typing.ClassVar[str] = ...
    TIME_SHIFT_COMMAND_TYPE_SET_PLAYBACK_PARAMS: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def notifyStateChanged(self, type: int | java.jint | java.lang.Integer, state: int | java.jint | java.lang.Integer, error: int | java.jint | java.lang.Integer, /) -> None: ...
    def onAppLinkCommand(self, command: android.os.Bundle, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onCreateSession(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> TvInteractiveAppService.Session | None: ...
    def onRegisterAppLinkInfo(self, appLinkInfo: AppLinkInfo, /) -> None: ...
    def onUnregisterAppLinkInfo(self, appLinkInfo: AppLinkInfo, /) -> None: ...

    class Session(android.view.KeyEvent.Callback):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def isMediaViewEnabled(self) -> bool: ...
        def layoutSurface(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyAdBufferReady(self, buffer: android.media.tv.AdBuffer, /) -> None: ...
        def notifyBiInteractiveAppCreated(self, biIAppUri: android.net.Uri, biIAppId: str | java.lang.String, /) -> None: ...
        def notifySessionStateChanged(self, state: int | java.jint | java.lang.Integer, err: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyTeletextAppStateChanged(self, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onAdBufferConsumed(self, buffer: android.media.tv.AdBuffer, /) -> None: ...
        def onAdResponse(self, response: android.media.tv.AdResponse, /) -> None: ...
        def onAvailableSpeeds(self, speeds: java.chaquopy.JavaArrayJFloat, /) -> None: ...
        def onBroadcastInfoResponse(self, response: android.media.tv.BroadcastInfoResponse, /) -> None: ...
        def onCertificate(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, cert: android.net.http.SslCertificate, /) -> None: ...
        def onContentAllowed(self) -> None: ...
        def onContentBlocked(self, rating: android.media.tv.TvContentRating, /) -> None: ...
        def onCreateBiInteractiveAppRequest(self, biIAppUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
        def onCreateMediaView(self) -> android.view.View: ...
        def onCurrentChannelLcn(self, lcn: int | java.jint | java.lang.Integer, /) -> None: ...
        def onCurrentChannelUri(self, channelUri: android.net.Uri, /) -> None: ...
        def onCurrentTvInputId(self, inputId: str | java.lang.String, /) -> None: ...
        def onCurrentVideoBounds(self, bounds: android.graphics.Rect, /) -> None: ...
        def onDestroyBiInteractiveAppRequest(self, biIAppId: str | java.lang.String, /) -> None: ...
        def onError(self, errMsg: str | java.lang.String, params: android.os.Bundle, /) -> None: ...
        def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onMediaViewSizeChanged(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRecordingConnectionFailed(self, recordingId: str | java.lang.String, inputId: str | java.lang.String, /) -> None: ...
        def onRecordingDisconnected(self, recordingId: str | java.lang.String, inputId: str | java.lang.String, /) -> None: ...
        def onRecordingError(self, recordingId: str | java.lang.String, err: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRecordingScheduled(self, recordingId: str | java.lang.String, requestId: str | java.lang.String, /) -> None: ...
        def onRecordingStarted(self, recordingId: str | java.lang.String, requestId: str | java.lang.String, /) -> None: ...
        def onRecordingStopped(self, recordingId: str | java.lang.String, /) -> None: ...
        def onRecordingTuned(self, recordingId: str | java.lang.String, channelUri: android.net.Uri, /) -> None: ...
        def onRelease(self) -> None: ...
        def onResetInteractiveApp(self) -> None: ...
        def onSelectedTrackInfo(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
        def onSetSurface(self, arg1: android.view.Surface, /) -> bool: ...
        def onSetTeletextAppEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onSignalStrength(self, strength: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSigningResult(self, signingId: str | java.lang.String, result: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onStartInteractiveApp(self) -> None: ...
        def onStopInteractiveApp(self) -> None: ...
        def onStreamVolume(self, volume: float | java.jfloat | java.lang.Float, /) -> None: ...
        def onSurfaceChanged(self, format: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftCurrentPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
        def onTimeShiftMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftPlaybackParams(self, params: android.media.PlaybackParams, /) -> None: ...
        def onTimeShiftStartPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
        def onTimeShiftStatusChanged(self, inputId: str | java.lang.String, status: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onTrackInfoList(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
        def onTrackSelected(self, type: int | java.jint | java.lang.Integer, trackId: str | java.lang.String, /) -> None: ...
        def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onTracksChanged(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
        def onTuned(self, channelUri: android.net.Uri, /) -> None: ...
        def onTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
        def onTvRecordingInfo(self, recordingInfo: android.media.tv.TvRecordingInfo, /) -> None: ...
        def onTvRecordingInfoList(self, recordingInfoList: java.util.List[android.media.tv.TvRecordingInfo], /) -> None: ...
        def onVideoAvailable(self) -> None: ...
        def onVideoFreezeUpdated(self, isFrozen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onVideoUnavailable(self, reason: int | java.jint | java.lang.Integer, /) -> None: ...
        def removeBroadcastInfo(self, requestId: int | java.jint | java.lang.Integer, /) -> None: ...
        def requestAd(self, request: android.media.tv.AdRequest, /) -> None: ...
        def requestAvailableSpeeds(self) -> None: ...
        def requestBroadcastInfo(self, request: android.media.tv.BroadcastInfoRequest, /) -> None: ...
        def requestCertificate(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, /) -> None: ...
        def requestCurrentChannelLcn(self) -> None: ...
        def requestCurrentChannelUri(self) -> None: ...
        def requestCurrentTvInputId(self) -> None: ...
        def requestCurrentVideoBounds(self) -> None: ...
        @typing.overload
        def requestScheduleRecording(self, requestId: str | java.lang.String, inputId: str | java.lang.String, channelUri: android.net.Uri, programUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
        @typing.overload
        def requestScheduleRecording(self, requestId: str | java.lang.String, inputId: str | java.lang.String, channelUri: android.net.Uri, startTime: int | java.jlong | java.lang.Long, duration: int | java.jlong | java.lang.Long, repeatDays: int | java.jint | java.lang.Integer, params: android.os.Bundle, /) -> None: ...
        def requestSelectedTrackInfo(self) -> None: ...
        @typing.overload
        def requestSigning(self, signingId: str | java.lang.String, algorithm: str | java.lang.String, alias: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        @typing.overload
        def requestSigning(self, signingId: str | java.lang.String, algorithm: str | java.lang.String, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def requestStartRecording(self, requestId: str | java.lang.String, programUri: android.net.Uri, /) -> None: ...
        def requestStopRecording(self, recordingId: str | java.lang.String, /) -> None: ...
        def requestStreamVolume(self) -> None: ...
        def requestTimeShiftMode(self) -> None: ...
        def requestTrackInfoList(self) -> None: ...
        def requestTvRecordingInfo(self, recordingId: str | java.lang.String, /) -> None: ...
        def requestTvRecordingInfoList(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
        def sendPlaybackCommandRequest(self, cmdType: str | java.lang.String, parameters: android.os.Bundle, /) -> None: ...
        def sendTimeShiftCommandRequest(self, cmdType: str | java.lang.String, parameters: android.os.Bundle, /) -> None: ...
        def setMediaViewEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setTvRecordingInfo(self, recordingId: str | java.lang.String, recordingInfo: android.media.tv.TvRecordingInfo, /) -> None: ...
        def setVideoBounds(self, rect: android.graphics.Rect, /) -> None: ...

class TvInteractiveAppServiceInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TvInteractiveAppServiceInfo]] = ...
    INTERACTIVE_APP_TYPE_ATSC: typing.ClassVar[int] = ...
    INTERACTIVE_APP_TYPE_GINGA: typing.ClassVar[int] = ...
    INTERACTIVE_APP_TYPE_HBBTV: typing.ClassVar[int] = ...
    INTERACTIVE_APP_TYPE_OTHER: typing.ClassVar[int] = ...
    INTERACTIVE_APP_TYPE_TARGETED_AD: typing.ClassVar[int] = ...
    def __init__(self, context: android.content.Context, component: android.content.ComponentName, /) -> None: ...
    def describeContents(self) -> int: ...
    def getCustomSupportedTypes(self) -> java.util.List[java.lang.String]: ...
    def getId(self) -> str: ...
    def getServiceInfo(self) -> android.content.pm.ServiceInfo | None: ...
    def getSupportedTypes(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TvInteractiveAppView(android.view.ViewGroup):
    BI_INTERACTIVE_APP_KEY_ALIAS: typing.ClassVar[str] = ...
    BI_INTERACTIVE_APP_KEY_CERTIFICATE: typing.ClassVar[str] = ...
    BI_INTERACTIVE_APP_KEY_HTTP_ADDITIONAL_HEADERS: typing.ClassVar[str] = ...
    BI_INTERACTIVE_APP_KEY_HTTP_USER_AGENT: typing.ClassVar[str] = ...
    BI_INTERACTIVE_APP_KEY_PRIVATE_KEY: typing.ClassVar[str] = ...
    ERROR_KEY_METHOD_NAME: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def clearCallback(self) -> None: ...
    def clearOnUnhandledInputEventListener(self) -> None: ...
    def createBiInteractiveApp(self, biIAppUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
    def destroyBiInteractiveApp(self, biIAppId: str | java.lang.String, /) -> None: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def getOnUnhandledInputEventListener(self) -> TvInteractiveAppView.OnUnhandledInputEventListener | None: ...
    def notifyError(self, errMsg: str | java.lang.String, params: android.os.Bundle, /) -> None: ...
    def notifyRecordingScheduled(self, recordingId: str | java.lang.String, requestId: str | java.lang.String, /) -> None: ...
    def notifyRecordingStarted(self, recordingId: str | java.lang.String, requestId: str | java.lang.String, /) -> None: ...
    def notifyRecordingStopped(self, recordingId: str | java.lang.String, /) -> None: ...
    def notifyTimeShiftCurrentPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def notifyTimeShiftPlaybackParams(self, params: android.media.PlaybackParams, /) -> None: ...
    def notifyTimeShiftStartPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def notifyTimeShiftStatusChanged(self, inputId: str | java.lang.String, status: int | java.jint | java.lang.Integer, /) -> None: ...
    def notifyTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
    def notifyVideoFreezeUpdated(self, isFrozen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def prepareInteractiveApp(self, iAppServiceId: str | java.lang.String, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def reset(self) -> None: ...
    def resetInteractiveApp(self) -> None: ...
    def sendAvailableSpeeds(self, speeds: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def sendCertificate(self, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, cert: android.net.http.SslCertificate, /) -> None: ...
    def sendCurrentChannelLcn(self, lcn: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendCurrentChannelUri(self, channelUri: android.net.Uri, /) -> None: ...
    def sendCurrentTvInputId(self, inputId: str | java.lang.String, /) -> None: ...
    def sendCurrentVideoBounds(self, bounds: android.graphics.Rect, /) -> None: ...
    def sendSelectedTrackInfo(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
    def sendSigningResult(self, signingId: str | java.lang.String, result: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def sendStreamVolume(self, volume: float | java.jfloat | java.lang.Float, /) -> None: ...
    def sendTimeShiftMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def sendTrackInfoList(self, tracks: java.util.List[android.media.tv.TvTrackInfo], /) -> None: ...
    def sendTvRecordingInfo(self, recordingInfo: android.media.tv.TvRecordingInfo, /) -> None: ...
    def sendTvRecordingInfoList(self, recordingInfoList: java.util.List[android.media.tv.TvRecordingInfo], /) -> None: ...
    def setCallback(self, executor: java.util.concurrent.Executor, callback: TvInteractiveAppView.TvInteractiveAppCallback, /) -> None: ...
    def setOnUnhandledInputEventListener(self, executor: java.util.concurrent.Executor, listener: TvInteractiveAppView.OnUnhandledInputEventListener, /) -> None: ...
    def setTeletextAppEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTvView(self, tvView: android.media.tv.TvView, /) -> int: ...
    def setZOrderMediaOverlay(self, isMediaOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZOrderOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startInteractiveApp(self) -> None: ...
    def stopInteractiveApp(self) -> None: ...

    class TvInteractiveAppCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onBiInteractiveAppCreated(self, iAppServiceId: str | java.lang.String, biIAppUri: android.net.Uri, biIAppId: str | java.lang.String, /) -> None: ...
        def onPlaybackCommandRequest(self, iAppServiceId: str | java.lang.String, cmdType: str | java.lang.String, parameters: android.os.Bundle, /) -> None: ...
        def onRequestAvailableSpeeds(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestCertificate(self, iAppServiceId: str | java.lang.String, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRequestCurrentChannelLcn(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestCurrentChannelUri(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestCurrentTvInputId(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestCurrentVideoBounds(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        @typing.overload
        def onRequestScheduleRecording(self, iAppServiceId: str | java.lang.String, requestId: str | java.lang.String, inputId: str | java.lang.String, channelUri: android.net.Uri, programUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
        @typing.overload
        def onRequestScheduleRecording(self, iAppServiceId: str | java.lang.String, requestId: str | java.lang.String, inputId: str | java.lang.String, channelUri: android.net.Uri, startTime: int | java.jlong | java.lang.Long, duration: int | java.jlong | java.lang.Long, repeatDays: int | java.jint | java.lang.Integer, params: android.os.Bundle, /) -> None: ...
        def onRequestSelectedTrackInfo(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        @typing.overload
        def onRequestSigning(self, iAppServiceId: str | java.lang.String, signingId: str | java.lang.String, algorithm: str | java.lang.String, alias: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        @typing.overload
        def onRequestSigning(self, iAppServiceId: str | java.lang.String, signingId: str | java.lang.String, algorithm: str | java.lang.String, host: str | java.lang.String, port: int | java.jint | java.lang.Integer, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def onRequestStartRecording(self, iAppServiceId: str | java.lang.String, requestId: str | java.lang.String, programUri: android.net.Uri, /) -> None: ...
        def onRequestStopRecording(self, iAppServiceId: str | java.lang.String, recordingId: str | java.lang.String, /) -> None: ...
        def onRequestStreamVolume(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestTimeShiftMode(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestTrackInfoList(self, iAppServiceId: str | java.lang.String, /) -> None: ...
        def onRequestTvRecordingInfo(self, iAppServiceId: str | java.lang.String, recordingId: str | java.lang.String, /) -> None: ...
        def onRequestTvRecordingInfoList(self, iAppServiceId: str | java.lang.String, type: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSetTvRecordingInfo(self, iAppServiceId: str | java.lang.String, recordingId: str | java.lang.String, recordingInfo: android.media.tv.TvRecordingInfo, /) -> None: ...
        def onSetVideoBounds(self, iAppServiceId: str | java.lang.String, rect: android.graphics.Rect, /) -> None: ...
        def onStateChanged(self, iAppServiceId: str | java.lang.String, state: int | java.jint | java.lang.Integer, err: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTeletextAppStateChanged(self, iAppServiceId: str | java.lang.String, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftCommandRequest(self, iAppServiceId: str | java.lang.String, cmdType: str | java.lang.String, parameters: android.os.Bundle, /) -> None: ...

    class OnUnhandledInputEventListener(java.lang.Object):
        def onUnhandledInputEvent(self, arg1: android.view.InputEvent, /) -> bool: ...



import typing

import android.app
import android.app.appsearch
import android.content
import android.content.pm
import android.os
import java
import java.lang
import java.util.concurrent

class AppFunctionException(android.os.Parcelable, java.lang.Exception):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppFunctionException]] = ...
    ERROR_APP_UNKNOWN_ERROR: typing.ClassVar[int] = ...
    ERROR_CANCELLED: typing.ClassVar[int] = ...
    ERROR_CATEGORY_APP: typing.ClassVar[int] = ...
    ERROR_CATEGORY_REQUEST_ERROR: typing.ClassVar[int] = ...
    ERROR_CATEGORY_SYSTEM: typing.ClassVar[int] = ...
    ERROR_CATEGORY_UNKNOWN: typing.ClassVar[int] = ...
    ERROR_DENIED: typing.ClassVar[int] = ...
    ERROR_DISABLED: typing.ClassVar[int] = ...
    ERROR_ENTERPRISE_POLICY_DISALLOWED: typing.ClassVar[int] = ...
    ERROR_FUNCTION_NOT_FOUND: typing.ClassVar[int] = ...
    ERROR_INVALID_ARGUMENT: typing.ClassVar[int] = ...
    ERROR_SYSTEM_ERROR: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getErrorCategory(self) -> int: ...
    def getErrorCode(self) -> int: ...
    def getErrorMessage(self) -> str: ...
    def getExtras(self) -> android.os.Bundle: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AppFunctionManager(java.lang.Object):
    APP_FUNCTION_STATE_DEFAULT: typing.ClassVar[int] = ...
    APP_FUNCTION_STATE_DISABLED: typing.ClassVar[int] = ...
    APP_FUNCTION_STATE_ENABLED: typing.ClassVar[int] = ...
    def executeAppFunction(self, request: ExecuteAppFunctionRequest, executor: java.util.concurrent.Executor, cancellationSignal: android.os.CancellationSignal, callback: android.os.OutcomeReceiver[ExecuteAppFunctionResponse, AppFunctionException], /) -> None: ...
    @typing.overload
    def isAppFunctionEnabled(self, functionIdentifier: str | java.lang.String, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Boolean, java.lang.Exception], /) -> None: ...
    @typing.overload
    def isAppFunctionEnabled(self, functionIdentifier: str | java.lang.String, targetPackage: str | java.lang.String, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Boolean, java.lang.Exception], /) -> None: ...
    def setAppFunctionEnabled(self, functionIdentifier: str | java.lang.String, newEnabledState: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, callback: android.os.OutcomeReceiver[java.lang.Void, java.lang.Exception], /) -> None: ...

class AppFunctionService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onExecuteFunction(self, arg1: ExecuteAppFunctionRequest, arg2: str | java.lang.String, arg3: android.content.pm.SigningInfo, arg4: android.os.CancellationSignal, arg5: android.os.OutcomeReceiver[ExecuteAppFunctionResponse, AppFunctionException], /) -> None: ...

class ExecuteAppFunctionRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ExecuteAppFunctionRequest]] = ...
    def describeContents(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getFunctionIdentifier(self) -> str: ...
    def getParameters(self) -> android.app.appsearch.GenericDocument: ...
    def getTargetPackageName(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, targetPackageName: str | java.lang.String, functionIdentifier: str | java.lang.String, /) -> None: ...
        def build(self) -> ExecuteAppFunctionRequest: ...
        def setExtras(self, extras: android.os.Bundle, /) -> ExecuteAppFunctionRequest.Builder: ...
        def setParameters(self, parameters: android.app.appsearch.GenericDocument, /) -> ExecuteAppFunctionRequest.Builder: ...

class ExecuteAppFunctionResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ExecuteAppFunctionResponse]] = ...
    PROPERTY_RETURN_VALUE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, resultDocument: android.app.appsearch.GenericDocument, /) -> None: ...
    @typing.overload
    def __init__(self, resultDocument: android.app.appsearch.GenericDocument, extras: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getResultDocument(self) -> android.app.appsearch.GenericDocument: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.util.stream

class Buffer(java.lang.Object):
    def array(self) -> java.lang.Object: ...
    def arrayOffset(self) -> int: ...
    def capacity(self) -> int: ...
    def clear(self) -> Buffer: ...
    def duplicate(self) -> Buffer: ...
    def flip(self) -> Buffer: ...
    def hasArray(self) -> bool: ...
    def hasRemaining(self) -> bool: ...
    def isDirect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    @typing.overload
    def limit(self) -> int: ...
    @typing.overload
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    @typing.overload
    def position(self) -> int: ...
    @typing.overload
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def remaining(self) -> int: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> Buffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> Buffer: ...

class BufferOverflowException(java.lang.RuntimeException):
    def __init__(self) -> None: ...

class BufferUnderflowException(java.lang.RuntimeException):
    def __init__(self) -> None: ...

class ByteBuffer(java.lang.Comparable[ByteBuffer], Buffer):
    def alignedSlice(self, unitSize: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    def alignmentOffset(self, index: int | java.jint | java.lang.Integer, unitSize: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @staticmethod
    def allocateDirect(capacity: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJByte: ...
    def arrayOffset(self) -> int: ...
    def asCharBuffer(self) -> CharBuffer: ...
    def asDoubleBuffer(self) -> DoubleBuffer: ...
    def asFloatBuffer(self) -> FloatBuffer: ...
    def asIntBuffer(self) -> IntBuffer: ...
    def asLongBuffer(self) -> LongBuffer: ...
    def asReadOnlyBuffer(self) -> ByteBuffer: ...
    def asShortBuffer(self) -> ShortBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> ByteBuffer: ...
    def compareTo(self, that: ByteBuffer, /) -> int: ...
    def duplicate(self) -> ByteBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> int: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJByte, /) -> ByteBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJByte, /) -> ByteBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def getChar(self) -> str: ...
    @typing.overload
    def getChar(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getDouble(self) -> float: ...
    @typing.overload
    def getDouble(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getFloat(self) -> float: ...
    @typing.overload
    def getFloat(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def getInt(self) -> int: ...
    @typing.overload
    def getInt(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLong(self) -> int: ...
    @typing.overload
    def getLong(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getShort(self) -> int: ...
    @typing.overload
    def getShort(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: ByteBuffer, /) -> int: ...
    @typing.overload
    def order(self) -> ByteOrder: ...
    @typing.overload
    def order(self, bo: ByteOrder, /) -> ByteBuffer: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: int | java.jbyte | java.lang.Byte, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, src: ByteBuffer, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJByte, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jbyte | java.lang.Byte, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJByte, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: ByteBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def putChar(self, arg1: str | java.jchar | java.lang.Character, /) -> ByteBuffer: ...
    @typing.overload
    def putChar(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.jchar | java.lang.Character, /) -> ByteBuffer: ...
    @typing.overload
    def putDouble(self, arg1: float | java.jdouble | java.lang.Double, /) -> ByteBuffer: ...
    @typing.overload
    def putDouble(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jdouble | java.lang.Double, /) -> ByteBuffer: ...
    @typing.overload
    def putFloat(self, arg1: float | java.jfloat | java.lang.Float, /) -> ByteBuffer: ...
    @typing.overload
    def putFloat(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> ByteBuffer: ...
    @typing.overload
    def putInt(self, arg1: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def putInt(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    @typing.overload
    def putLong(self, arg1: int | java.jlong | java.lang.Long, /) -> ByteBuffer: ...
    @typing.overload
    def putLong(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> ByteBuffer: ...
    @typing.overload
    def putShort(self, arg1: int | java.jshort | java.lang.Short, /) -> ByteBuffer: ...
    @typing.overload
    def putShort(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jshort | java.lang.Short, /) -> ByteBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> ByteBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJByte, /) -> ByteBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ByteBuffer: ...

class ByteOrder(java.lang.Object):
    BIG_ENDIAN: typing.ClassVar[ByteOrder] = ...
    LITTLE_ENDIAN: typing.ClassVar[ByteOrder] = ...
    @staticmethod
    def nativeOrder() -> ByteOrder: ...
    def toString(self) -> str: ...

class CharBuffer(java.lang.Appendable, java.lang.CharSequence, java.lang.Comparable[CharBuffer], java.lang.Readable, Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    def append(self, c: str | java.jchar | java.lang.Character, /) -> CharBuffer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, /) -> CharBuffer: ...
    @typing.overload
    def append(self, csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJChar: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> CharBuffer: ...
    def charAt(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def chars(self) -> java.util.stream.IntStream: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> CharBuffer: ...
    def compareTo(self, that: CharBuffer, /) -> int: ...
    def duplicate(self) -> CharBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> str: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJChar, /) -> CharBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJChar, /) -> CharBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def length(self) -> int: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: CharBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: str | java.jchar | java.lang.Character, /) -> CharBuffer: ...
    @typing.overload
    def put(self, src: str | java.lang.String, /) -> CharBuffer: ...
    @typing.overload
    def put(self, src: CharBuffer, /) -> CharBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJChar, /) -> CharBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.jchar | java.lang.Character, /) -> CharBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJChar, /) -> CharBuffer: ...
    @typing.overload
    def put(self, src: str | java.lang.String, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: CharBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    def read(self, target: CharBuffer, /) -> int: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> CharBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    def subSequence(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(csq: java.lang.CharSequence, /) -> CharBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJChar, /) -> CharBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(csq: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJChar, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> CharBuffer: ...

class DoubleBuffer(java.lang.Comparable[DoubleBuffer], Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJDouble: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> DoubleBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> DoubleBuffer: ...
    def compareTo(self, that: DoubleBuffer, /) -> int: ...
    def duplicate(self) -> DoubleBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> float: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJDouble, /) -> DoubleBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJDouble, /) -> DoubleBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJDouble, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJDouble, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: DoubleBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: float | java.jdouble | java.lang.Double, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, src: DoubleBuffer, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJDouble, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jdouble | java.lang.Double, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJDouble, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJDouble, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: DoubleBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJDouble, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> DoubleBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJDouble, /) -> DoubleBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJDouble, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> DoubleBuffer: ...

class FloatBuffer(java.lang.Comparable[FloatBuffer], Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJFloat: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> FloatBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> FloatBuffer: ...
    def compareTo(self, that: FloatBuffer, /) -> int: ...
    def duplicate(self) -> FloatBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> float: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> float: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJFloat, /) -> FloatBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJFloat, /) -> FloatBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: FloatBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: float | java.jfloat | java.lang.Float, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, src: FloatBuffer, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJFloat, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJFloat, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: FloatBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> FloatBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJFloat, /) -> FloatBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJFloat, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> FloatBuffer: ...

class IntBuffer(java.lang.Comparable[IntBuffer], Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJInt: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> IntBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> IntBuffer: ...
    def compareTo(self, that: IntBuffer, /) -> int: ...
    def duplicate(self) -> IntBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> int: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJInt, /) -> IntBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJInt, /) -> IntBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: IntBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    @typing.overload
    def put(self, src: IntBuffer, /) -> IntBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJInt, /) -> IntBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJInt, /) -> IntBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: IntBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> IntBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJInt, /) -> IntBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJInt, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> IntBuffer: ...

class InvalidMarkException(java.lang.IllegalStateException):
    def __init__(self) -> None: ...

class LongBuffer(java.lang.Comparable[LongBuffer], Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJLong: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> LongBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> LongBuffer: ...
    def compareTo(self, that: LongBuffer, /) -> int: ...
    def duplicate(self) -> LongBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> int: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJLong, /) -> LongBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJLong, /) -> LongBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJLong, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJLong, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: LongBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, arg1: int | java.jlong | java.lang.Long, /) -> LongBuffer: ...
    @typing.overload
    def put(self, src: LongBuffer, /) -> LongBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJLong, /) -> LongBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> LongBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJLong, /) -> LongBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJLong, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: LongBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJLong, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> LongBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJLong, /) -> LongBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJLong, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> LongBuffer: ...

class MappedByteBuffer(ByteBuffer):
    def clear(self) -> Buffer: ...
    def compact(self) -> ByteBuffer: ...
    def duplicate(self) -> ByteBuffer: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def force(self) -> MappedByteBuffer: ...
    @typing.overload
    def force(self, index: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> MappedByteBuffer: ...
    def isLoaded(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def load(self) -> MappedByteBuffer: ...
    def mark(self) -> Buffer: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> ByteBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> MappedByteBuffer: ...

class ReadOnlyBufferException(java.lang.UnsupportedOperationException):
    def __init__(self) -> None: ...

class ShortBuffer(java.lang.Comparable[ShortBuffer], Buffer):
    @staticmethod
    def allocate(capacity: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    def array(self) -> java.chaquopy.JavaArrayJShort: ...
    def arrayOffset(self) -> int: ...
    def asReadOnlyBuffer(self) -> ShortBuffer: ...
    def clear(self) -> Buffer: ...
    def compact(self) -> ShortBuffer: ...
    def compareTo(self, that: ShortBuffer, /) -> int: ...
    def duplicate(self) -> ShortBuffer: ...
    def equals(self, ob: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flip(self) -> Buffer: ...
    @typing.overload
    def get(self) -> int: ...
    @typing.overload
    def get(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJShort, /) -> ShortBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJShort, /) -> ShortBuffer: ...
    @typing.overload
    def get(self, dst: java.chaquopy.JavaArrayJShort, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    @typing.overload
    def get(self, index: int | java.jint | java.lang.Integer, dst: java.chaquopy.JavaArrayJShort, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    def hasArray(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isDirect(self) -> bool: ...
    def limit(self, newLimit: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    def mark(self) -> Buffer: ...
    def mismatch(self, that: ShortBuffer, /) -> int: ...
    def order(self) -> ByteOrder: ...
    def position(self, newPosition: int | java.jint | java.lang.Integer, /) -> Buffer: ...
    @typing.overload
    def put(self, src: ShortBuffer, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jshort | java.lang.Short, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJShort, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jshort | java.lang.Short, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJShort, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, src: java.chaquopy.JavaArrayJShort, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: ShortBuffer, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    @typing.overload
    def put(self, index: int | java.jint | java.lang.Integer, src: java.chaquopy.JavaArrayJShort, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    def reset(self) -> Buffer: ...
    def rewind(self) -> Buffer: ...
    @typing.overload
    def slice(self) -> ShortBuffer: ...
    @typing.overload
    def slice(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
    def toString(self) -> str: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJShort, /) -> ShortBuffer: ...
    @typing.overload
    @staticmethod
    def wrap(array: java.chaquopy.JavaArrayJShort, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> ShortBuffer: ...
